@@ -106,7 +106,7 @@ def cli(configfile, observed_since, setup_only=False, troubleshoot=False):
             product='JiraCloud',
             build=__version__
         )
-        if int(tio.sessions.details().get('permissions')) < 64:
+        if int(source.sessions.details().get('permissions')) < 64:
             logging.error('API Keys tie to non-admin user.')
     elif config['tenable'].get('platform') == 'tenable.sc':
         source = TenableSC(
